import { useMainContext } from "../../layout/MainProvider";
import { PostType, Prisma } from "@nice/common";
import PostList from "@web/src/components/models/course/list/PostList";
import { useMemo } from "react";
import CourseCard from "./CourseCard";

export function CoursesContainer() {
	const { selectedTerms, searchCondition } = useMainContext();
	const termFilters = useMemo(() => {
		return Object.entries(selectedTerms)
			.filter(([, terms]) => terms.length > 0)
			.map(([, terms]) => terms);
	}, [selectedTerms]);

	return (
		<>
			<PostList
				renderItem={(post) => <CourseCard course={post} edit={false}></CourseCard>}
				params={{
					pageSize: 12,
					where: {
						type: PostType.COURSE,
						AND: termFilters.map((termFilter) => ({
							terms: {
								some: {
									id: {
										in: termFilter, // 确保至少有一个 term.id 在当前 termFilter 中
									},
								},
							},
						})),
						...searchCondition,
					},
				}}
				cols={4}></PostList>
		</>
	);
}

export default CoursesContainer;
