import { Checkbox, Divider, Radio, Space, Spin } from "antd";

import { TaxonomySlug, TermDto } from "@nice/common";

import { useEffect, useMemo, useState } from "react";
import { api } from "@nice/client";
import { useSearchParams } from "react-router-dom";
import TermSelect from "@web/src/components/models/term/term-select";
import { useMainContext } from "../../layout/MainProvider";
import TermParentSelector from "@web/src/components/models/term/term-parent-selector";

export default function FilterSection() {
	const { data: taxonomies } = api.taxonomy.getAll.useQuery({});
	const { selectedTerms, setSelectedTerms } = useMainContext();
	const handleTermChange = (slug: string, selected: string[]) => {
		setSelectedTerms({
			...selectedTerms,
			[slug]: selected, // 更新对应 slug 的选择
		});
	};
	return (
		<div className=" flex z-0 p-6 flex-col rounded-lg mt-4   space-y-6 h-[820px]  overscroll-contain overflow-x-hidden">
			{taxonomies?.map((tax, index) => {
				const items = Object.entries(selectedTerms).find(
					([key, items]) => key === tax.slug
				)?.[1];
				return (
					<div key={index}>
						<h3 className="text-lg font-medium mb-4">
							{tax?.name}
						</h3>
						<TermParentSelector
							value={items}
							slug={tax?.slug}
							className="w-70 max-h-[400px] overscroll-contain overflow-x-hidden"
							onChange={(selected) =>
								handleTermChange(
									tax?.slug,
									selected as string[]
								)
							}
							taxonomyId={tax?.id}></TermParentSelector>
						<Divider></Divider>
					</div>
				);
			})}
		</div>
	);
}
